# psfcube

[![PyPI](https://img.shields.io/pypi/v/psfcube.svg?style=flat-square)](https://pypi.python.org/pypi/psfcube)


Module to fit 3D PSF on IFU data


# Installation

`pip install psfcube` (favored)

or

```bash
git pull https://github.com/MickaelRigault/psfcube.git
cd psfcube
python setup.py install
```

# Dependencies

(Dependencies will automatically be installed with using pip)

- numpy, scipy, matplotlib, astropy

- minuit (pip install iminuit)
- modefit (pip install modefit)
